@@ -3,7 +3,7 @@ function(x,sa,n=nrow(x),incx=1) {
 if (missing(sa)) messagena("sa")
 mdx <- length(x)
 if (missing(x)) x <- double(mdx)
-f.res <- .Fortran("scald",
+f.res <- .Fortran("scalzd",
 x=as.double(x),
 sa=to.single(sa),
 n=to.integer(n),
